﻿using System;
using System.Collections.ObjectModel;
using System.Drawing;
using System.IO;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WmsServerEdition;

namespace ThinkGeo.MapSuite.NearMapPlugins
{
    public class NearMapPlugin : WmsLayerPlugin
    {
        private const string SrsDecimalDegree = "EPSG:4326";

        public NearMapPlugin()
        {
            BrowerCacheExpiration = TimeSpan.FromSeconds(0);
            WmsQueryMode = WmsQueryMode.Queryable;
        }

        protected override RectangleShape GetBoundingBoxCore(string crs)
        {
            return new RectangleShape(-126.826171875, 57.104766845702, -70.83984375, 18.960235595702);
        }

        protected override MapConfiguration GetMapConfigurationCore(string style, string crs)
        {
            MapConfiguration mapConfiguration = new MapConfiguration();

            var nearApiKey = "";
            var nearUrl = "https://wmsus.nearmap.com/wms";
            var nearUri = new Uri(nearUrl);
            var nearRasterLayer = new WmsRasterLayer(nearUri);
            nearRasterLayer.Parameters.Add("httpauth", "false");
            nearRasterLayer.Parameters.Add("apikey", nearApiKey);
            mapConfiguration.Layers.Add(nearRasterLayer);
            
            //// Use shape file to do WMS service test
            //string worldLayerFilePath = "Your shape file path";
            //// Create the world layer from a shapefile and add a style to it
            //ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(worldLayerFilePath);
            //worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;
            //worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            //// Create a MapConfiguration and add the layer to it            
            //mapConfiguration.Layers.Add("WorldLayer", worldLayer);

            return mapConfiguration;
        }

        protected override string GetNameCore()
        {
            return "WorldMap";
        }

        protected override Collection<string> GetProjectionsCore()
        {
            return new Collection<string> { SrsDecimalDegree };
        }

        protected override GeographyUnit GetGeographyUnitCore(string crs)
        {
            return GeographyUnit.DecimalDegree;
        }
    }
}
